==> haskell-mysql-0.2.1-186.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mysql
version:              0.2.1
visibility:           public
id:                   mysql-0.2.1-IYNrdn8zmc85a8mxVRVIHo
key:                  mysql-0.2.1-IYNrdn8zmc85a8mxVRVIHo
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2013 Bryan O'\''Sullivan <bos@serpentine.com>

maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql
synopsis:             A low-level MySQL client library.
description:
    A low-level client library for the MySQL database, implemented as
    bindings to the C @mysqlclient@ API.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  0a83f30d717d6e8701b5b1c1d849dc6f
exposed:              True
exposed-modules:
    Database.MySQL.Base Database.MySQL.Base.C Database.MySQL.Base.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/mysql-0.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mysql-0.2.1 /usr/lib/
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mysql-0.2.1 /usr/lib/
dynamic-library-dirs: /usr/lib /usr/lib/
data-dir:             /usr/share/haskell-mysql
hs-libraries:         HSmysql-0.2.1-IYNrdn8zmc85a8mxVRVIHo
extra-libraries:      z dl m ssl crypto mariadb
include-dirs:         /usr/include/mysql /usr/include/mysql/mysql
depends:              base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-mysql/html/mysql.haddock
haddock-html:         /usr/share/doc/haskell-mysql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mysql-0.2.1-187-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mysql
version:              0.2.1
visibility:           public
id:                   mysql-0.2.1-7hwMuxCIs5qHLFpGGyaXU4
key:                  mysql-0.2.1-7hwMuxCIs5qHLFpGGyaXU4
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2013 Bryan O'\''Sullivan <bos@serpentine.com>

maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql
synopsis:             A low-level MySQL client library.
description:
    A low-level client library for the MySQL database, implemented as
    bindings to the C @mysqlclient@ API.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  24ff11e16d086883167876d96bc4d351
exposed:              True
exposed-modules:
    Database.MySQL.Base Database.MySQL.Base.C Database.MySQL.Base.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/mysql-0.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/mysql-0.2.1 /usr/lib/
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/mysql-0.2.1 /usr/lib/
dynamic-library-dirs: /usr/lib /usr/lib/
data-dir:             /usr/share/haskell-mysql
hs-libraries:         HSmysql-0.2.1-7hwMuxCIs5qHLFpGGyaXU4
extra-libraries:      z dl m ssl crypto mariadb
include-dirs:         /usr/include/mysql /usr/include/mysql/mysql
depends:              base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-mysql/html/mysql.haddock
haddock-html:         /usr/share/doc/haskell-mysql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
